gegl r1984 - in trunk: . gegl gegl/graph gegl/operation gegl/process operations/affine operations/color operations/core operations/enhance operations/io operations/render operations/workshop



Author: ok
Date: Sat Feb  9 20:18:01 2008
New Revision: 1984
URL: http://svn.gnome.org/viewvc/gegl?rev=1984&view=rev

Log:
%s/get_defined_region/get_bounding_box/g
%s/compute_affected_region/get_required_for_output/g
%s/compute_input_request/get_invalidated_by_change/g
* gegl/gegl-old-chant.h:
* gegl/gegl-plugin.h:
* gegl/graph/gegl-node-context.c:
* gegl/graph/gegl-node.c:
* gegl/operation/gegl-operation-area-filter.c:
* gegl/operation/gegl-operation-composer.c:
* gegl/operation/gegl-operation-filter.c:
* gegl/operation/gegl-operation-sink.c:
* gegl/operation/gegl-operation-source.c:
* gegl/operation/gegl-operation.c:
* gegl/operation/gegl-operation.h:
* gegl/operation/gegl-operations.c:
* gegl/process/gegl-have-visitor.c:
* operations/affine/affine.c:
* operations/color/remap.c:
* operations/color/stretch-contrast.c:
* operations/core/clone.c:
* operations/core/crop.c: 
* operations/core/shift.c:
* operations/enhance/bilateral-filter.c:
* operations/enhance/snn-mean.c:
* operations/io/ff-load.c: 
* operations/io/jpg-load.c:
* operations/io/load-buffer.c:
* operations/io/magick-load.c:
* operations/io/pixbuf.c:
* operations/io/png-load.c:
* operations/io/raw-load.c:
* operations/io/save-pixbuf.c:
* operations/io/svg-load.c:
* operations/render/checkerboard.c:
* operations/render/color.c:
* operations/render/fractal-explorer.c:
* operations/render/introspect.c:
* operations/render/noise.c:
* operations/render/text.c: 
* operations/workshop/box-percentile.c:
* operations/workshop/c2g.c:
* operations/workshop/demosaic-simple.c:
* operations/workshop/disc-percentile.c:
* operations/workshop/gluas.c:
* operations/workshop/hstack.c:
* operations/workshop/kuwahara-max.c:
* operations/workshop/kuwahara-min.c:
* operations/workshop/kuwahara.c:
* operations/workshop/lens-correct.c:
* operations/workshop/line-profile.c:
* operations/workshop/mandelbrot.c:
* operations/workshop/max-envelope.c:
* operations/workshop/min-envelope.c:
* operations/workshop/rawbayer-load.c:
* operations/workshop/snn-percentile.c:
* operations/workshop/stress.c:


Modified:
   trunk/ChangeLog
   trunk/gegl/gegl-old-chant.h
   trunk/gegl/gegl-plugin.h
   trunk/gegl/graph/gegl-node-context.c
   trunk/gegl/graph/gegl-node.c
   trunk/gegl/operation/gegl-operation-area-filter.c
   trunk/gegl/operation/gegl-operation-composer.c
   trunk/gegl/operation/gegl-operation-filter.c
   trunk/gegl/operation/gegl-operation-sink.c
   trunk/gegl/operation/gegl-operation-source.c
   trunk/gegl/operation/gegl-operation.c
   trunk/gegl/operation/gegl-operation.h
   trunk/gegl/operation/gegl-operations.c
   trunk/gegl/process/gegl-have-visitor.c
   trunk/operations/affine/affine.c
   trunk/operations/color/remap.c
   trunk/operations/color/stretch-contrast.c
   trunk/operations/core/clone.c
   trunk/operations/core/crop.c
   trunk/operations/core/shift.c
   trunk/operations/enhance/bilateral-filter.c
   trunk/operations/enhance/snn-mean.c
   trunk/operations/io/ff-load.c
   trunk/operations/io/jpg-load.c
   trunk/operations/io/load-buffer.c
   trunk/operations/io/magick-load.c
   trunk/operations/io/pixbuf.c
   trunk/operations/io/png-load.c
   trunk/operations/io/raw-load.c
   trunk/operations/io/save-pixbuf.c
   trunk/operations/io/svg-load.c
   trunk/operations/render/checkerboard.c
   trunk/operations/render/color.c
   trunk/operations/render/fractal-explorer.c
   trunk/operations/render/introspect.c
   trunk/operations/render/noise.c
   trunk/operations/render/text.c
   trunk/operations/workshop/box-percentile.c
   trunk/operations/workshop/c2g.c
   trunk/operations/workshop/demosaic-simple.c
   trunk/operations/workshop/disc-percentile.c
   trunk/operations/workshop/gluas.c
   trunk/operations/workshop/hstack.c
   trunk/operations/workshop/kuwahara-max.c
   trunk/operations/workshop/kuwahara-min.c
   trunk/operations/workshop/kuwahara.c
   trunk/operations/workshop/lens-correct.c
   trunk/operations/workshop/line-profile.c
   trunk/operations/workshop/mandelbrot.c
   trunk/operations/workshop/max-envelope.c
   trunk/operations/workshop/min-envelope.c
   trunk/operations/workshop/rawbayer-load.c
   trunk/operations/workshop/snn-percentile.c
   trunk/operations/workshop/stress.c

Modified: trunk/gegl/gegl-old-chant.h
==============================================================================
--- trunk/gegl/gegl-old-chant.h	(original)
+++ trunk/gegl/gegl-old-chant.h	Sat Feb  9 20:18:01 2008
@@ -579,7 +579,7 @@
 #endif
 
 #ifdef GEGL_CHANT_SOURCE
-static GeglRectangle get_defined_region (GeglOperation *self);
+static GeglRectangle get_bounding_box (GeglOperation *self);
 #endif
 
 static void
@@ -618,7 +618,7 @@
 #endif
 
 #ifdef GEGL_CHANT_SOURCE
-  operation_class->get_defined_region = get_defined_region;
+  operation_class->get_bounding_box = get_bounding_box;
 #endif
 
 #define M_GEGL_CHANT_SET_NAME_EXTENDED(nam) \

Modified: trunk/gegl/gegl-plugin.h
==============================================================================
--- trunk/gegl/gegl-plugin.h	(original)
+++ trunk/gegl/gegl-plugin.h	Sat Feb  9 20:18:01 2008
@@ -159,23 +159,23 @@
    * (is already implemented in GeglOperationPointFilter and
    * GeglOperationPointComposer, GeglOperationAreaFilter base classes.
    */
-  GeglRectangle   (*get_defined_region)   (GeglOperation *operation);
+  GeglRectangle   (*get_bounding_box)   (GeglOperation *operation);
 
   /* Computes the region in output (same affected rect assumed for all outputs)
    * when a given region has changed on an input. Used to aggregate dirt in the
    * graph. A default implementation of this, if not provided should probably
    * be to report that the entire defined region is dirtied.
    */
-  GeglRectangle   (*compute_affected_region)  (GeglOperation       *operation,
+  GeglRectangle   (*get_required_for_output)  (GeglOperation       *operation,
                                                const gchar         *input_pad,
                                                const GeglRectangle *input_region);
 
   /* computes the rectangle needed to be correctly computed in a buffer
    * on the named input_pad, for a given result rectangle
    */
-  GeglRectangle   (*compute_input_request) (GeglOperation       *operation,
-                                            const gchar         *input_pad,
-                                            const GeglRectangle *roi);
+  GeglRectangle   (*get_invalidated_by_change) (GeglOperation       *operation,
+                                                const gchar         *input_pad,
+                                                const GeglRectangle *roi);
 
   /* Adjust result rect, adapts the rectangle used for computing results.
    * (useful for global operations like contrast stretching, as well as
@@ -207,7 +207,7 @@
 GType           gegl_operation_get_type             (void) G_GNUC_CONST;
 
 /* retrieves the bounding box of a connected input */
-GeglRectangle * gegl_operation_source_get_defined_region (GeglOperation *operation,
+GeglRectangle * gegl_operation_source_get_bounding_box (GeglOperation *operation,
                                                           const gchar   *pad_name);
 
 
@@ -219,22 +219,22 @@
 
 
 /* retrieves the node providing data to a named input pad */
-GeglNode      * gegl_operation_get_source_node      (GeglOperation *operation,
-                                                     const gchar   *pad_name);
-GeglRectangle   gegl_operation_compute_affected_region (GeglOperation *operation,
-                                                     const gchar   *input_pad,
-                                                     const GeglRectangle *input_region);
-GeglRectangle   gegl_operation_get_defined_region   (GeglOperation *operation);
-GeglRectangle   gegl_operation_adjust_result_region (GeglOperation *operation,
-                                                     const GeglRectangle *roi);
-
-GeglRectangle   gegl_operation_compute_input_request(GeglOperation *operation,
-                                                     const gchar   *input_pad,
-                                                     const GeglRectangle *roi);
-
-GeglNode       *gegl_operation_detect               (GeglOperation *operation,
-                                                     gint           x,
-                                                     gint           y);
+GeglNode      * gegl_operation_get_source_node           (GeglOperation *operation,
+                                                          const gchar   *pad_name);
+GeglRectangle   gegl_operation_get_required_for_output   (GeglOperation *operation,
+                                                          const gchar   *input_pad,
+                                                          const GeglRectangle *input_region);
+GeglRectangle   gegl_operation_get_bounding_box          (GeglOperation *operation);
+GeglRectangle   gegl_operation_adjust_result_region      (GeglOperation *operation,
+                                                          const GeglRectangle *roi);
+
+GeglRectangle   gegl_operation_get_invalidated_by_change (GeglOperation *operation,
+                                                          const gchar   *input_pad,
+                                                          const GeglRectangle *roi);
+
+GeglNode       *gegl_operation_detect                    (GeglOperation *operation,
+                                                          gint           x,
+                                                          gint           y);
 
 
 /* virtual method invokers that change behavior based on the roi being computed,

Modified: trunk/gegl/graph/gegl-node-context.c
==============================================================================
--- trunk/gegl/graph/gegl-node-context.c	(original)
+++ trunk/gegl/graph/gegl-node-context.c	Sat Feb  9 20:18:01 2008
@@ -368,9 +368,8 @@
  
   node = context->node;
   operation = node->operation;
-  input_request  = gegl_operation_compute_input_request (operation,
-                                                         padname,
-                                                         &context->need_rect);
+  input_request  = gegl_operation_get_invalidated_by_change (
+                                   operation, padname, &context->need_rect);
 
   real_input = GEGL_BUFFER (gegl_node_context_get_object (context, padname));
   if (!real_input)

Modified: trunk/gegl/graph/gegl-node.c
==============================================================================
--- trunk/gegl/graph/gegl-node.c	(original)
+++ trunk/gegl/graph/gegl-node.c	Sat Feb  9 20:18:01 2008
@@ -534,7 +534,7 @@
   if (destination->operation)
     {
       dirty_rect =
-        gegl_operation_compute_affected_region (destination->operation,
+        gegl_operation_get_required_for_output (destination->operation,
                                                 gegl_pad_get_name (destination_pad),
                                                 rect);
     }

Modified: trunk/gegl/operation/gegl-operation-area-filter.c
==============================================================================
--- trunk/gegl/operation/gegl-operation-area-filter.c	(original)
+++ trunk/gegl/operation/gegl-operation-area-filter.c	Sat Feb  9 20:18:01 2008
@@ -33,14 +33,14 @@
 #include "buffer/gegl-buffer.h"
 
 
-static void          prepare                 (GeglOperation       *operation);
-static GeglRectangle get_defined_region      (GeglOperation       *operation);
-static GeglRectangle compute_input_request   (GeglOperation       *operation,
-                                              const gchar         *input_pad,
-                                              const GeglRectangle *region);
-static GeglRectangle compute_affected_region (GeglOperation       *operation,
-                                              const gchar         *input_pad,
-                                              const GeglRectangle *input_region);
+static void          prepare                  (GeglOperation       *operation);
+static GeglRectangle get_bounding_box          (GeglOperation       *operation);
+static GeglRectangle get_invalidated_by_change (GeglOperation       *operation,
+                                                 const gchar         *input_pad,
+                                                 const GeglRectangle *region);
+static GeglRectangle get_required_for_output   (GeglOperation       *operation,
+                                                 const gchar         *input_pad,
+                                                 const GeglRectangle *input_region);
 
 G_DEFINE_TYPE (GeglOperationAreaFilter, gegl_operation_area_filter,
                GEGL_TYPE_OPERATION_FILTER)
@@ -51,9 +51,9 @@
   GeglOperationClass *operation_class = GEGL_OPERATION_CLASS (klass);
 
   operation_class->prepare = prepare;
-  operation_class->get_defined_region  = get_defined_region;
-  operation_class->compute_affected_region = compute_affected_region;
-  operation_class->compute_input_request = compute_input_request;
+  operation_class->get_bounding_box = get_bounding_box;
+  operation_class->get_required_for_output = get_required_for_output;
+  operation_class->get_invalidated_by_change = get_invalidated_by_change;
 }
 
 static void
@@ -72,14 +72,13 @@
 }
 
 static GeglRectangle
-get_defined_region (GeglOperation *operation)
+get_bounding_box (GeglOperation *operation)
 {
   GeglOperationAreaFilter *area = GEGL_OPERATION_AREA_FILTER (operation);
   GeglRectangle            result = { 0, };
   GeglRectangle           *in_rect;
 
-  in_rect = gegl_operation_source_get_defined_region (operation,
-                                                      "input");
+  in_rect = gegl_operation_source_get_bounding_box (operation,"input");
 
   if (!in_rect)
     return result;
@@ -98,15 +97,15 @@
 }
 
 static GeglRectangle
-compute_input_request (GeglOperation       *operation,
-                       const gchar         *input_pad,
-                       const GeglRectangle *region)
+get_invalidated_by_change (GeglOperation       *operation,
+                           const gchar         *input_pad,
+                           const GeglRectangle *region)
 {
   GeglOperationAreaFilter *area = GEGL_OPERATION_AREA_FILTER (operation);
   GeglRectangle            rect;
   GeglRectangle            defined;
 
-  defined = get_defined_region (operation);
+  defined = get_bounding_box (operation);
   gegl_rectangle_intersect (&rect, region, &defined);
 
   if (rect.width  != 0 &&
@@ -122,7 +121,7 @@
 }
 
 static GeglRectangle
-compute_affected_region (GeglOperation       *operation,
+get_required_for_output (GeglOperation       *operation,
                          const gchar         *input_pad,
                          const GeglRectangle *input_region)
 {

Modified: trunk/gegl/operation/gegl-operation-composer.c
==============================================================================
--- trunk/gegl/operation/gegl-operation-composer.c	(original)
+++ trunk/gegl/operation/gegl-operation-composer.c	Sat Feb  9 20:18:01 2008
@@ -56,11 +56,10 @@
                               gint                 x,
                               gint                 y);
 
-static GeglRectangle get_defined_region    (GeglOperation       *self);
-static GeglRectangle compute_input_request (GeglOperation       *self,
-                                            const gchar         *input_pad,
-                                            const GeglRectangle *roi);
-
+static GeglRectangle get_bounding_box          (GeglOperation       *self);
+static GeglRectangle get_invalidated_by_change (GeglOperation       *self,
+                                                 const gchar         *input_pad,
+                                                 const GeglRectangle *roi);
 
 G_DEFINE_TYPE (GeglOperationComposer, gegl_operation_composer,
                GEGL_TYPE_OPERATION)
@@ -78,8 +77,8 @@
   operation_class->process = process;
   operation_class->attach = attach;
   operation_class->detect = detect;
-  operation_class->get_defined_region = get_defined_region;
-  operation_class->compute_input_request = compute_input_request;
+  operation_class->get_bounding_box = get_bounding_box;
+  operation_class->get_invalidated_by_change = get_invalidated_by_change;
 
   g_object_class_install_property (object_class, PROP_OUTPUT,
                                    g_param_spec_object ("output",
@@ -188,11 +187,11 @@
 }
 
 static GeglRectangle
-get_defined_region (GeglOperation *self)
+get_bounding_box (GeglOperation *self)
 {
   GeglRectangle  result   = { 0, 0, 0, 0 };
-  GeglRectangle *in_rect  = gegl_operation_source_get_defined_region (self, "input");
-  GeglRectangle *aux_rect = gegl_operation_source_get_defined_region (self, "aux");
+  GeglRectangle *in_rect  = gegl_operation_source_get_bounding_box (self, "input");
+  GeglRectangle *aux_rect = gegl_operation_source_get_bounding_box (self, "aux");
 
   if (!in_rect)
     {
@@ -212,9 +211,9 @@
 }
 
 static GeglRectangle
-compute_input_request (GeglOperation       *self,
-                       const gchar         *input_pad,
-                       const GeglRectangle *roi)
+get_invalidated_by_change (GeglOperation       *self,
+                           const gchar         *input_pad,
+                           const GeglRectangle *roi)
 {
   GeglRectangle rect = *roi;
   return rect;

Modified: trunk/gegl/operation/gegl-operation-filter.c
==============================================================================
--- trunk/gegl/operation/gegl-operation-filter.c	(original)
+++ trunk/gegl/operation/gegl-operation-filter.c	Sat Feb  9 20:18:01 2008
@@ -58,10 +58,10 @@
                                          gint           x,
                                          gint           y);
 
-static GeglRectangle get_defined_region    (GeglOperation       *self);
-static GeglRectangle compute_input_request (GeglOperation       *operation,
-                                            const gchar         *input_pad,
-                                            const GeglRectangle *roi);
+static GeglRectangle get_bounding_box          (GeglOperation       *self);
+static GeglRectangle get_invalidated_by_change (GeglOperation       *operation,
+                                                 const gchar         *input_pad,
+                                                 const GeglRectangle *roi);
 
 
 G_DEFINE_TYPE (GeglOperationFilter, gegl_operation_filter, GEGL_TYPE_OPERATION)
@@ -76,11 +76,11 @@
   object_class->set_property = set_property;
   object_class->get_property = get_property;
 
-  operation_class->process               = process;
-  operation_class->attach                = attach;
-  operation_class->detect                = detect;
-  operation_class->get_defined_region    = get_defined_region;
-  operation_class->compute_input_request = compute_input_request;
+  operation_class->process                   = process;
+  operation_class->attach                    = attach;
+  operation_class->detect                    = detect;
+  operation_class->get_bounding_box          = get_bounding_box;
+  operation_class->get_invalidated_by_change = get_invalidated_by_change;
 
   g_object_class_install_property (object_class, PROP_OUTPUT,
                                    g_param_spec_object ("output",
@@ -222,12 +222,12 @@
 }
 
 static GeglRectangle
-get_defined_region (GeglOperation *self)
+get_bounding_box (GeglOperation *self)
 {
   GeglRectangle  result = { 0, 0, 0, 0 };
   GeglRectangle *in_rect;
 
-  in_rect = gegl_operation_source_get_defined_region (self, "input");
+  in_rect = gegl_operation_source_get_bounding_box (self, "input");
   if (in_rect)
     {
       result = *in_rect;
@@ -237,9 +237,9 @@
 }
 
 static GeglRectangle
-compute_input_request (GeglOperation       *operation,
-                       const gchar         *input_pad,
-                       const GeglRectangle *roi)
+get_invalidated_by_change (GeglOperation       *operation,
+                           const gchar         *input_pad,
+                           const GeglRectangle *roi)
 {
   GeglRectangle result = *roi;
   return result;

Modified: trunk/gegl/operation/gegl-operation-sink.c
==============================================================================
--- trunk/gegl/operation/gegl-operation-sink.c	(original)
+++ trunk/gegl/operation/gegl-operation-sink.c	Sat Feb  9 20:18:01 2008
@@ -43,15 +43,15 @@
                                             const GValue        *value,
                                             GParamSpec          *pspec);
 
-static gboolean      process               (GeglOperation       *operation,
-                                            GeglNodeContext     *context,
-                                            const gchar         *output_prop,
-                                            const GeglRectangle *result);
-static void          attach                (GeglOperation       *operation);
-static GeglRectangle get_defined_region    (GeglOperation       *self);
-static GeglRectangle compute_input_request (GeglOperation       *operation,
-                                            const gchar         *input_pad,
-                                            const GeglRectangle *roi);
+static gboolean      process                   (GeglOperation       *operation,
+                                                 GeglNodeContext     *context,
+                                                 const gchar         *output_prop,
+                                                 const GeglRectangle *result);
+static void          attach                   (GeglOperation       *operation);
+static GeglRectangle get_bounding_box          (GeglOperation       *self);
+static GeglRectangle get_invalidated_by_change (GeglOperation       *operation,
+                                                 const gchar         *input_pad,
+                                                 const GeglRectangle *roi);
 
 
 G_DEFINE_TYPE (GeglOperationSink, gegl_operation_sink, GEGL_TYPE_OPERATION)
@@ -70,8 +70,8 @@
 
   operation_class->process               = process;
   operation_class->attach                = attach;
-  operation_class->get_defined_region    = get_defined_region;
-  operation_class->compute_input_request = compute_input_request;
+  operation_class->get_bounding_box    = get_bounding_box;
+  operation_class->get_invalidated_by_change = get_invalidated_by_change;
 
   g_object_class_install_property (object_class, PROP_INPUT,
                                    g_param_spec_object ("input",
@@ -141,12 +141,12 @@
 }
 
 static GeglRectangle
-get_defined_region (GeglOperation *self)
+get_bounding_box (GeglOperation *self)
 {
   GeglRectangle  result = { 0, 0, 0, 0 };
   GeglRectangle *in_rect;
 
-  in_rect = gegl_operation_source_get_defined_region (self, "input");
+  in_rect = gegl_operation_source_get_bounding_box (self, "input");
   if (in_rect)
     {
       result = *in_rect;
@@ -156,9 +156,9 @@
 }
 
 static GeglRectangle
-compute_input_request (GeglOperation       *operation,
-                       const gchar         *input_pad,
-                       const GeglRectangle *roi)
+get_invalidated_by_change (GeglOperation       *operation,
+                           const gchar         *input_pad,
+                           const GeglRectangle *roi)
 {
   GeglRectangle rect=*roi;
   return rect;

Modified: trunk/gegl/operation/gegl-operation-source.c
==============================================================================
--- trunk/gegl/operation/gegl-operation-source.c	(original)
+++ trunk/gegl/operation/gegl-operation-source.c	Sat Feb  9 20:18:01 2008
@@ -51,12 +51,12 @@
 
 G_DEFINE_TYPE (GeglOperationSource, gegl_operation_source, GEGL_TYPE_OPERATION)
 
-static GeglRectangle get_defined_region    (GeglOperation       *self);
-static GeglRectangle compute_input_request (GeglOperation       *operation,
-                                            const gchar         *input_pad,
-                                            const GeglRectangle *roi);
-static GeglRectangle  adjust_result_region (GeglOperation       *operation,
-                                            const GeglRectangle *roi);
+static GeglRectangle get_bounding_box          (GeglOperation       *self);
+static GeglRectangle get_invalidated_by_change (GeglOperation       *operation,
+                                                 const gchar         *input_pad,
+                                                 const GeglRectangle *roi);
+static GeglRectangle  adjust_result_region     (GeglOperation       *operation,
+                                                 const GeglRectangle *roi);
 
 
 static void
@@ -72,8 +72,8 @@
   operation_class->attach  = attach;
   operation_class->adjust_result_region = adjust_result_region;
 
-  operation_class->get_defined_region  = get_defined_region;
-  operation_class->compute_input_request = compute_input_request;
+  operation_class->get_bounding_box  = get_bounding_box;
+  operation_class->get_invalidated_by_change = get_invalidated_by_change;
 
   g_object_class_install_property (gobject_class, PROP_OUTPUT,
                                    g_param_spec_object ("output",
@@ -140,7 +140,7 @@
 }
 
 static GeglRectangle
-get_defined_region (GeglOperation *self)
+get_bounding_box (GeglOperation *self)
 {
   GeglRectangle result = { 0, 0, 0, 0 };
 
@@ -150,9 +150,9 @@
 }
 
 static GeglRectangle
-compute_input_request (GeglOperation       *operation,
-                       const gchar         *input_pad,
-                       const GeglRectangle *roi)
+get_invalidated_by_change (GeglOperation       *operation,
+                           const gchar         *input_pad,
+                           const GeglRectangle *roi)
 {
   return *roi;
 }

Modified: trunk/gegl/operation/gegl-operation.c
==============================================================================
--- trunk/gegl/operation/gegl-operation.c	(original)
+++ trunk/gegl/operation/gegl-operation.c	Sat Feb  9 20:18:01 2008
@@ -36,13 +36,13 @@
 
 static void          attach                  (GeglOperation       *self);
 
-static GeglRectangle get_defined_region      (GeglOperation       *self);
-static GeglRectangle compute_affected_region (GeglOperation       *self,
-                                              const gchar         *input_pad,
-                                              const GeglRectangle *input_region);
-static GeglRectangle compute_input_request   (GeglOperation       *self,
-                                              const gchar         *input_pad,
-                                              const GeglRectangle *region);
+static GeglRectangle get_bounding_box            (GeglOperation       *self);
+static GeglRectangle get_required_for_output     (GeglOperation       *self,
+                                                   const gchar         *input_pad,
+                                                   const GeglRectangle *input_region);
+static GeglRectangle get_invalidated_by_change   (GeglOperation       *self,
+                                                   const gchar         *input_pad,
+                                                   const Geg lRectangle *region);
 
 G_DEFINE_TYPE (GeglOperation, gegl_operation, G_TYPE_OBJECT)
 
@@ -54,14 +54,14 @@
                                            * included when doing
                                            * operation lookup by
                                            * name */
-  klass->description             = NULL;
-  klass->categories              = NULL;
-  klass->attach                  = attach;
-  klass->prepare                 = NULL;
-  klass->no_cache                = FALSE;
-  klass->get_defined_region      = get_defined_region;
-  klass->compute_affected_region = compute_affected_region;
-  klass->compute_input_request   = compute_input_request;
+  klass->description               = NULL;
+  klass->categories                = NULL;
+  klass->attach                    = attach;
+  klass->prepare                   = NULL;
+  klass->no_cache                  = FALSE;
+  klass->get_bounding_box          = get_bounding_box;
+  klass->get_required_for_output   = get_required_for_output;
+  klass->get_invalidated_by_change = get_invalidated_by_change;
 }
 
 static void
@@ -123,19 +123,19 @@
 }
 
 GeglRectangle
-gegl_operation_get_defined_region (GeglOperation *self)
+gegl_operation_get_bounding_box (GeglOperation *self)
 {
   GeglOperationClass *klass = GEGL_OPERATION_GET_CLASS (self);
   GeglRectangle       rect  = { 0, 0, 0, 0 };
 
-  if (klass->get_defined_region)
-    return klass->get_defined_region (self);
+  if (klass->get_bounding_box)
+    return klass->get_bounding_box (self);
 
   return rect;
 }
 
 GeglRectangle
-gegl_operation_compute_affected_region (GeglOperation       *self,
+gegl_operation_get_required_for_output (GeglOperation       *self,
                                         const gchar         *input_pad,
                                         const GeglRectangle *input_region)
 {
@@ -152,29 +152,29 @@
       input_region->height == 0)
     return *input_region;
 
-  if (klass->compute_affected_region)
-    return klass->compute_affected_region (self, input_pad, input_region);
+  if (klass->get_required_for_output)
+    return klass->get_required_for_output (self, input_pad, input_region);
 
   return *input_region;
 }
 
 static GeglRectangle
-compute_input_request (GeglOperation       *operation,
-                       const gchar         *input_pad,
-                       const GeglRectangle *roi)
+get_invalidated_by_change (GeglOperation       *operation,
+                           const gchar         *input_pad,
+                           const GeglRectangle *roi)
 {
   GeglRectangle result = *roi;
 
   if (operation->node->is_graph)
     {
-      return gegl_operation_compute_input_request (operation, input_pad, roi);
+      return gegl_operation_get_invalidated_by_change (operation, input_pad, roi);
     }
 
   return result;
 }
 
 GeglRectangle
-gegl_operation_compute_input_request (GeglOperation       *operation,
+gegl_operation_get_invalidated_by_change (GeglOperation       *operation,
                                       const gchar         *input_pad,
                                       const GeglRectangle *roi)
 {
@@ -184,9 +184,9 @@
       roi->height == 0)
     return *roi;
 
-  g_assert (klass->compute_input_request);
+  g_assert (klass->get_invalidated_by_change);
 
-  return klass->compute_input_request (operation, input_pad, roi);
+  return klass->get_invalidated_by_change (operation, input_pad, roi);
 }
 
 
@@ -267,7 +267,7 @@
 }
 
 GeglRectangle *
-gegl_operation_source_get_defined_region (GeglOperation *operation,
+gegl_operation_source_get_bounding_box (GeglOperation *operation,
                                           const gchar   *input_pad_name)
 {
   GeglNode *node = gegl_operation_get_source_node (operation, input_pad_name);
@@ -333,13 +333,13 @@
 }
 
 static GeglRectangle
-get_defined_region (GeglOperation *self)
+get_bounding_box (GeglOperation *self)
 {
   GeglRectangle rect = { 0, 0, 0, 0 };
 
   if (self->node->is_graph)
     {
-      return gegl_operation_get_defined_region (
+      return gegl_operation_get_bounding_box (
                gegl_node_get_output_proxy (self->node, "output")->operation);
     }
   g_warning ("Op '%s' has no defined_region method",
@@ -348,13 +348,13 @@
 }
 
 static GeglRectangle
-compute_affected_region (GeglOperation       *self,
+get_required_for_output (GeglOperation       *self,
                          const gchar         *input_pad,
                          const GeglRectangle *input_region)
 {
   if (self->node->is_graph)
     {
-      return gegl_operation_compute_affected_region (
+      return gegl_operation_get_required_for_output (
                gegl_node_get_output_proxy (self->node, "output")->operation,
                input_pad,
                input_region);

Modified: trunk/gegl/operation/gegl-operation.h
==============================================================================
--- trunk/gegl/operation/gegl-operation.h	(original)
+++ trunk/gegl/operation/gegl-operation.h	Sat Feb  9 20:18:01 2008
@@ -74,23 +74,23 @@
    * (is already implemented in GeglOperationPointFilter and
    * GeglOperationPointComposer, GeglOperationAreaFilter base classes.
    */
-  GeglRectangle   (*get_defined_region)   (GeglOperation *operation);
+  GeglRectangle   (*get_bounding_box)   (GeglOperation *operation);
 
   /* Computes the region in output (same affected rect assumed for all outputs)
    * when a given region has changed on an input. Used to aggregate dirt in the
    * graph. A default implementation of this, if not provided should probably
    * be to report that the entire defined region is dirtied.
    */
-  GeglRectangle   (*compute_affected_region)  (GeglOperation       *operation,
+  GeglRectangle   (*get_required_for_output)  (GeglOperation       *operation,
                                                const gchar         *input_pad,
                                                const GeglRectangle *input_region);
 
   /* computes the rectangle needed to be correctly computed in a buffer
    * on the named input_pad, for a given result rectangle
    */
-  GeglRectangle   (*compute_input_request) (GeglOperation       *operation,
-                                            const gchar         *input_pad,
-                                            const GeglRectangle *roi);
+  GeglRectangle   (*get_invalidated_by_change) (GeglOperation       *operation,
+                                                const gchar         *input_pad,
+                                                const GeglRectangle *roi);
 
   /* Adjust result rect, adapts the rectangle used for computing results.
    * (useful for global operations like contrast stretching, as well as
@@ -122,7 +122,7 @@
 GType           gegl_operation_get_type             (void) G_GNUC_CONST;
 
 /* retrieves the bounding box of a connected input */
-GeglRectangle * gegl_operation_source_get_defined_region (GeglOperation *operation,
+GeglRectangle * gegl_operation_source_get_bounding_box (GeglOperation *operation,
                                                           const gchar   *pad_name);
 
 
@@ -134,22 +134,22 @@
 
 
 /* retrieves the node providing data to a named input pad */
-GeglNode      * gegl_operation_get_source_node      (GeglOperation *operation,
-                                                     const gchar   *pad_name);
-GeglRectangle   gegl_operation_compute_affected_region (GeglOperation *operation,
-                                                     const gchar   *input_pad,
-                                                     const GeglRectangle *input_region);
-GeglRectangle   gegl_operation_get_defined_region   (GeglOperation *operation);
-GeglRectangle   gegl_operation_adjust_result_region (GeglOperation *operation,
-                                                     const GeglRectangle *roi);
-
-GeglRectangle   gegl_operation_compute_input_request(GeglOperation *operation,
-                                                     const gchar   *input_pad,
-                                                     const GeglRectangle *roi);
-
-GeglNode       *gegl_operation_detect               (GeglOperation *operation,
-                                                     gint           x,
-                                                     gint           y);
+GeglNode      * gegl_operation_get_source_node         (GeglOperation *operation,
+                                                        const gchar   *pad_name);
+GeglRectangle   gegl_operation_get_required_for_output (GeglOperation *operation,
+                                                        const gchar   *input_pad,
+                                                        const GeglRectangle *input_region);
+GeglRectangle   gegl_operation_get_bounding_box        (GeglOperation *operation);
+GeglRectangle   gegl_operation_adjust_result_region    (GeglOperation *operation,
+                                                        const GeglRectangle *roi);
+
+GeglRectangle   gegl_operation_get_invalidated_by_change(GeglOperation *operation,
+                                                         const gchar   *input_pad,
+                                                         const GeglRectangle *roi);
+
+GeglNode       *gegl_operation_detect                   (GeglOperation *operation,
+                                                         gint           x,
+                                                         gint           y);
 
 
 /* virtual method invokers that change behavior based on the roi being computed,

Modified: trunk/gegl/operation/gegl-operations.c
==============================================================================
--- trunk/gegl/process/gegl-have-visitor.c	(original)
+++ trunk/gegl/process/gegl-have-visitor.c	Sat Feb  9 20:18:01 2008
@@ -65,7 +65,7 @@
   operation = node->operation;
   if (!operation)
     return;
-  rect = gegl_operation_get_defined_region (operation);
+  rect = gegl_operation_get_bounding_box (operation);
 
   node->have_rect = rect;
 

Modified: trunk/operations/affine/affine.c
==============================================================================
--- trunk/operations/affine/affine.c	(original)
+++ trunk/operations/affine/affine.c	Sat Feb  9 20:18:01 2008
@@ -60,11 +60,11 @@
 static gboolean      is_composite_node       (OpAffine            *affine);
 static void          get_source_matrix       (OpAffine            *affine,
                                               Matrix3              output);
-static GeglRectangle get_defined_region      (GeglOperation       *op);
-static GeglRectangle compute_affected_region (GeglOperation       *operation,
+static GeglRectangle get_bounding_box       (GeglOperation       *op);
+static GeglRectangle get_required_for_output (GeglOperation       *operation,
                                               const gchar         *input_pad,
                                               const GeglRectangle *input_region);
-static GeglRectangle compute_input_request   (GeglOperation       *self,
+static GeglRectangle get_invalidated_by_change(GeglOperation       *self,
                                               const gchar         *input_pad,
                                               const GeglRectangle *region);
 
@@ -140,9 +140,9 @@
   gobject_class->set_property = set_property;
   gobject_class->get_property = get_property;
 
-  op_class->compute_affected_region = compute_affected_region;
-  op_class->get_defined_region  = get_defined_region;
-  op_class->compute_input_request = compute_input_request;
+  op_class->get_required_for_output = get_required_for_output;
+  op_class->get_bounding_box  = get_bounding_box;
+  op_class->get_invalidated_by_change = get_invalidated_by_change;
   op_class->detect = detect;
   op_class->categories = "transform";
   op_class->prepare = prepare;
@@ -347,7 +347,7 @@
 }
 
 static GeglRectangle
-get_defined_region (GeglOperation *op)
+get_bounding_box (GeglOperation *op)
 {
   OpAffine      *affine  = (OpAffine *) op;
   OpAffineClass *klass   = OP_AFFINE_GET_CLASS (affine);
@@ -356,8 +356,8 @@
   gdouble        have_points [8];
   gint           i;
 
-  if (gegl_operation_source_get_defined_region (op, "input"))
-  in_rect = *gegl_operation_source_get_defined_region (op, "input");
+  if (gegl_operation_source_get_bounding_box (op, "input"))
+  in_rect = *gegl_operation_source_get_bounding_box (op, "input");
 
   /* invoke child's matrix creation function */
   g_assert (klass->create_matrix);
@@ -449,9 +449,9 @@
 }
 
 static GeglRectangle
-compute_input_request (GeglOperation       *op,
-                       const gchar         *input_pad,
-                       const GeglRectangle *region)
+get_invalidated_by_change (GeglOperation       *op,
+                           const gchar         *input_pad,
+                           const GeglRectangle *region)
 {
   OpAffine      *affine = (OpAffine *) op;
   Matrix3        inverse;
@@ -511,7 +511,7 @@
 }
 
 static GeglRectangle
-compute_affected_region (GeglOperation       *op,
+get_required_for_output (GeglOperation        *op,
                          const gchar         *input_pad,
                          const GeglRectangle *input_region)
 {

Modified: trunk/operations/color/remap.c
==============================================================================
--- trunk/operations/color/remap.c	(original)
+++ trunk/operations/color/remap.c	Sat Feb  9 20:18:01 2008
@@ -76,12 +76,12 @@
 }
 
 static GeglRectangle
-get_defined_region (GeglOperation *operation)
+get_bounding_box (GeglOperation *operation)
 {
   GeglRectangle  result = { 0, 0, 0, 0 };
   GeglRectangle *in_rect;
 
-  in_rect = gegl_operation_source_get_defined_region (operation, "input");
+  in_rect = gegl_operation_source_get_bounding_box (operation, "input");
   if (in_rect)
     {
       result = *in_rect;
@@ -91,7 +91,7 @@
 }
 
 static GeglRectangle
-compute_affected_region (GeglOperation       *operation,
+get_required_for_output (GeglOperation       *operation,
                          const gchar         *input_pad,
                          const GeglRectangle *input_region)
 {
@@ -99,9 +99,9 @@
 }
 
 static GeglRectangle
-compute_input_request (GeglOperation       *operation,
-                       const gchar         *input_pad,
-                       const GeglRectangle *roi)
+get_invalidated_by_change (GeglOperation       *operation,
+                           const gchar         *input_pad,
+                           const GeglRectangle *roi)
 {
   return *roi;
 }
@@ -179,9 +179,9 @@
   operation_class->attach  = attach;
   operation_class->prepare = prepare;
   operation_class->detect  = detect;
-  operation_class->get_defined_region = get_defined_region;
-  operation_class->compute_affected_region = compute_affected_region;
-  operation_class->compute_input_request = compute_input_request;
+  operation_class->get_bounding_box = get_bounding_box;
+  operation_class->get_required_for_output = get_required_for_output;
+  operation_class->get_invalidated_by_change = get_invalidated_by_change;
 
   operation_class->name        = "remap";
   operation_class->categories  = "color";

Modified: trunk/operations/color/stretch-contrast.c
==============================================================================
--- trunk/operations/color/stretch-contrast.c	(original)
+++ trunk/operations/color/stretch-contrast.c	Sat Feb  9 20:18:01 2008
@@ -83,11 +83,11 @@
 }
 
 static GeglRectangle
-compute_input_request (GeglOperation       *operation,
-                       const gchar         *input_pad,
-                       const GeglRectangle *roi)
+get_invalidated_by_change (GeglOperation       *operation,
+                           const gchar         *input_pad,
+                           const GeglRectangle *roi)
 {
-  GeglRectangle result = *gegl_operation_source_get_defined_region (operation, "input");
+  GeglRectangle result = *gegl_operation_source_get_bounding_box (operation, "input");
   return result;
 }
 
@@ -144,7 +144,7 @@
 
   filter_class->process = process;
   operation_class->prepare = prepare;
-  operation_class->compute_input_request = compute_input_request;
+  operation_class->get_invalidated_by_change = get_invalidated_by_change;
 
   operation_class->name        = "stretch-contrast";
   operation_class->categories  = "color:enhance";

Modified: trunk/operations/core/clone.c
==============================================================================
--- trunk/operations/core/clone.c	(original)
+++ trunk/operations/core/clone.c	Sat Feb  9 20:18:01 2008
@@ -50,12 +50,12 @@
 }
 
 static GeglRectangle
-get_defined_region (GeglOperation *operation)
+get_bounding_box (GeglOperation *operation)
 {
   GeglRectangle  result = { 0, 0, 0, 0 };
   GeglRectangle *in_rect;
 
-  in_rect = gegl_operation_source_get_defined_region (operation, "input");
+  in_rect = gegl_operation_source_get_bounding_box (operation, "input");
   if (in_rect)
     {
       result = *in_rect;
@@ -96,7 +96,7 @@
 
   operation_class = GEGL_OPERATION_CLASS (klass);
   operation_class->process = process;
-  operation_class->get_defined_region = get_defined_region;
+  operation_class->get_bounding_box = get_bounding_box;
   operation_class->detect = detect;
 
   operation_class->name        = "clone";

Modified: trunk/operations/core/crop.c
==============================================================================
--- trunk/operations/core/crop.c	(original)
+++ trunk/operations/core/crop.c	Sat Feb  9 20:18:01 2008
@@ -52,10 +52,10 @@
 
 
 static GeglRectangle
-get_defined_region (GeglOperation *operation)
+get_bounding_box (GeglOperation *operation)
 {
   GeglChantO    *o = GEGL_CHANT_PROPERTIES (operation);
-  GeglRectangle *in_rect = gegl_operation_source_get_defined_region (operation, "input");
+  GeglRectangle *in_rect = gegl_operation_source_get_bounding_box (operation, "input");
   GeglRectangle  result  = { 0, 0, 0, 0 };
 
   if (!in_rect)
@@ -70,7 +70,7 @@
 }
 
 static GeglRectangle
-compute_affected_region (GeglOperation       *operation,
+get_required_for_output (GeglOperation       *operation,
                          const gchar         *input_pad,
                          const GeglRectangle *input_region)
 {
@@ -83,9 +83,9 @@
 }
 
 static GeglRectangle
-compute_input_request (GeglOperation       *operation,
-                       const gchar         *input_pad,
-                       const GeglRectangle *roi)
+get_invalidated_by_change (GeglOperation       *operation,
+                           const gchar         *input_pad,
+                           const GeglRectangle *roi)
 {
   return *roi;
 }
@@ -137,11 +137,11 @@
 
   operation_class = GEGL_OPERATION_CLASS (klass);
   operation_class->process = process;
-  operation_class->get_defined_region = get_defined_region;
+  operation_class->get_bounding_box = get_bounding_box;
   operation_class->detect = detect;
-  operation_class->compute_affected_region = compute_affected_region;
-  operation_class->get_defined_region = get_defined_region;
-  operation_class->compute_input_request = compute_input_request;
+  operation_class->get_required_for_output = get_required_for_output;
+  operation_class->get_bounding_box = get_bounding_box;
+  operation_class->get_invalidated_by_change = get_invalidated_by_change;
 
   operation_class->name        = "crop";
   operation_class->categories  = "core";

Modified: trunk/operations/core/shift.c
==============================================================================
--- trunk/operations/core/shift.c	(original)
+++ trunk/operations/core/shift.c	Sat Feb  9 20:18:01 2008
@@ -62,10 +62,10 @@
 }
 
 static GeglRectangle
-get_defined_region (GeglOperation *operation)
+get_bounding_box (GeglOperation *operation)
 {
   GeglChantO    *o = GEGL_CHANT_PROPERTIES (operation);
-  GeglRectangle *in_rect = gegl_operation_source_get_defined_region (operation, "input");
+  GeglRectangle *in_rect = gegl_operation_source_get_bounding_box (operation, "input");
   GeglRectangle  result  = { 0, 0, 0, 0 };
 
   if (!in_rect)
@@ -80,7 +80,7 @@
 }
 
 static GeglRectangle
-compute_affected_region (GeglOperation       *operation,
+get_required_for_output (GeglOperation       *operation,
                          const gchar         *input_pad,
                          const GeglRectangle *input_region)
 {
@@ -94,9 +94,9 @@
 }
 
 static GeglRectangle
-compute_input_request (GeglOperation       *operation,
-                       const gchar         *input_pad,
-                       const GeglRectangle *roi)
+get_invalidated_by_change (GeglOperation       *operation,
+                           const gchar         *input_pad,
+                           const GeglRectangle *roi)
 {
   GeglChantO   *o = GEGL_CHANT_PROPERTIES (operation);
   GeglRectangle result = *roi;
@@ -168,9 +168,9 @@
   operation_class->process                 = process;
   operation_class->attach                  = attach;
   operation_class->detect                  = detect;
-  operation_class->get_defined_region      = get_defined_region;
-  operation_class->compute_input_request   = compute_input_request;
-  operation_class->compute_affected_region = compute_affected_region;
+  operation_class->get_bounding_box      = get_bounding_box;
+  operation_class->get_invalidated_by_change   = get_invalidated_by_change;
+  operation_class->get_required_for_output = get_required_for_output;
 
   operation_class->name        = "shift";
   operation_class->categories  = "core";

Modified: trunk/operations/enhance/bilateral-filter.c
==============================================================================
--- trunk/operations/enhance/bilateral-filter.c	(original)
+++ trunk/operations/enhance/bilateral-filter.c	Sat Feb  9 20:18:01 2008
@@ -61,8 +61,8 @@
   GeglBuffer   *temp_in;
   GeglRectangle compute;
 
-  compute = gegl_operation_compute_input_request (operation,
-                                                  "input", result);
+  compute = gegl_operation_get_invalidated_by_change (
+                   operation, "input", result);
 
   if (o->blur_radius < 1.0)
     {

Modified: trunk/operations/enhance/snn-mean.c
==============================================================================
--- trunk/operations/enhance/snn-mean.c	(original)
+++ trunk/operations/enhance/snn-mean.c	Sat Feb  9 20:18:01 2008
@@ -59,8 +59,8 @@
   GeglBuffer          *temp_in;
   GeglRectangle        compute;
 
-  compute  = gegl_operation_compute_input_request (operation,
-                                                   "input", result);
+  compute  = gegl_operation_get_invalidated_by_change (
+                   operation, "input", result);
 
   if (o->radius < 1.0)
     {

Modified: trunk/operations/io/ff-load.c
==============================================================================
--- trunk/operations/io/ff-load.c	(original)
+++ trunk/operations/io/ff-load.c	Sat Feb  9 20:18:01 2008
@@ -403,7 +403,7 @@
 }
 
 static GeglRectangle
-get_defined_region (GeglOperation *operation)
+get_bounding_box (GeglOperation *operation)
 {
   GeglRectangle result = {0,0,320,200};
   Priv *p = (Priv*)GEGL_CHANT_OPERATION (operation)->priv;

Modified: trunk/operations/io/jpg-load.c
==============================================================================
--- trunk/operations/io/jpg-load.c	(original)
+++ trunk/operations/io/jpg-load.c	Sat Feb  9 20:18:01 2008
@@ -124,7 +124,7 @@
 }
 
 static GeglRectangle
-get_defined_region (GeglOperation *operation)
+get_bounding_box (GeglOperation *operation)
 {
   GeglChantO   *o = GEGL_CHANT_PROPERTIES (operation);
   GeglRectangle result = {0,0,0,0};
@@ -192,7 +192,7 @@
   source_class    = GEGL_OPERATION_SOURCE_CLASS (klass);
 
   source_class->process = process;
-  operation_class->get_defined_region = get_defined_region;
+  operation_class->get_bounding_box = get_bounding_box;
 
   operation_class->name        = "jpg-load";
   operation_class->categories  = "hidden";

Modified: trunk/operations/io/load-buffer.c
==============================================================================
--- trunk/operations/io/load-buffer.c	(original)
+++ trunk/operations/io/load-buffer.c	Sat Feb  9 20:18:01 2008
@@ -64,7 +64,7 @@
 }
 
 static GeglRectangle
-get_defined_region (GeglOperation *operation)
+get_bounding_box (GeglOperation *operation)
 {
   GeglRectangle result = {0,0,0,0};
   GeglChantOperation *self = GEGL_CHANT_OPERATION (operation);

Modified: trunk/operations/io/magick-load.c
==============================================================================
--- trunk/operations/io/magick-load.c	(original)
+++ trunk/operations/io/magick-load.c	Sat Feb  9 20:18:01 2008
@@ -107,7 +107,7 @@
 
 
 static GeglRectangle
-get_defined_region (GeglOperation *operation)
+get_bounding_box (GeglOperation *operation)
 {
   GeglRectangle result = {0,0,0,0};
   GeglChantOperation *self = GEGL_CHANT_OPERATION (operation);

Modified: trunk/operations/io/pixbuf.c
==============================================================================
--- trunk/operations/io/pixbuf.c	(original)
+++ trunk/operations/io/pixbuf.c	Sat Feb  9 20:18:01 2008
@@ -27,7 +27,7 @@
 #include <gdk-pixbuf/gdk-pixdata.h>
 
 static GeglRectangle
-get_defined_region (GeglOperation *operation)
+get_bounding_box (GeglOperation *operation)
 {
   GeglChantO   *o = GEGL_CHANT_PROPERTIES (operation);
   GeglRectangle result = {0,0,0,0};
@@ -85,7 +85,7 @@
 
   /*source_class->process = process;*/
   source_class->process = process;
-  operation_class->get_defined_region = get_defined_region;
+  operation_class->get_bounding_box = get_bounding_box;
   operation_class->prepare = prepare;
   /*operation_class->no_cache = TRUE;*/
 

Modified: trunk/operations/io/png-load.c
==============================================================================
--- trunk/operations/io/png-load.c	(original)
+++ trunk/operations/io/png-load.c	Sat Feb  9 20:18:01 2008
@@ -349,7 +349,7 @@
 }
 
 static GeglRectangle
-get_defined_region (GeglOperation *operation)
+get_bounding_box (GeglOperation *operation)
 {
   GeglChantO   *o = GEGL_CHANT_PROPERTIES (operation);
   GeglRectangle result = {0,0,0,0};
@@ -414,7 +414,7 @@
   source_class    = GEGL_OPERATION_SOURCE_CLASS (klass);
 
   source_class->process = process;
-  operation_class->get_defined_region = get_defined_region;
+  operation_class->get_bounding_box = get_bounding_box;
 
   operation_class->name        = "png-load";
   operation_class->categories  = "hidden";

Modified: trunk/operations/io/raw-load.c
==============================================================================
--- trunk/operations/io/raw-load.c	(original)
+++ trunk/operations/io/raw-load.c	Sat Feb  9 20:18:01 2008
@@ -67,7 +67,7 @@
 
 
 static GeglRectangle
-get_defined_region (GeglOperation *operation)
+get_bounding_box (GeglOperation *operation)
 {
   GeglRectangle result = {0,0,0,0};
   GeglChantOperation *self = GEGL_CHANT_OPERATION (operation);

Modified: trunk/operations/io/save-pixbuf.c
==============================================================================
--- trunk/operations/io/save-pixbuf.c	(original)
+++ trunk/operations/io/save-pixbuf.c	Sat Feb  9 20:18:01 2008
@@ -41,7 +41,7 @@
       const Babl       *babl;
       const BablFormat *format;
       guchar           *temp;
-      GeglRectangle *rect = gegl_operation_source_get_defined_region (operation, "input");
+      GeglRectangle *rect = gegl_operation_source_get_bounding_box (operation, "input");
       gchar *name;
       gboolean has_alpha;
       gint bps;

Modified: trunk/operations/io/svg-load.c
==============================================================================
--- trunk/operations/io/svg-load.c	(original)
+++ trunk/operations/io/svg-load.c	Sat Feb  9 20:18:01 2008
@@ -147,7 +147,7 @@
 }
 
 static GeglRectangle
-get_defined_region (GeglOperation *operation)
+get_bounding_box (GeglOperation *operation)
 {
   GeglChantO   *o = GEGL_CHANT_PROPERTIES (operation);
   GeglRectangle result = {0,0,0,0};
@@ -232,7 +232,7 @@
   source_class    = GEGL_OPERATION_SOURCE_CLASS (klass);
 
   source_class->process = process;
-  operation_class->get_defined_region = get_defined_region;
+  operation_class->get_bounding_box = get_bounding_box;
 
   operation_class->name        = "svg-load";
   operation_class->categories  = "input";   /* not hidden because it has extra API */

Modified: trunk/operations/render/checkerboard.c
==============================================================================
--- trunk/operations/render/checkerboard.c	(original)
+++ trunk/operations/render/checkerboard.c	Sat Feb  9 20:18:01 2008
@@ -44,7 +44,7 @@
 }
 
 static GeglRectangle
-get_defined_region (GeglOperation *operation)
+get_bounding_box (GeglOperation *operation)
 {
   GeglRectangle result = {-10000000, -10000000, 20000000, 20000000};
   return result;
@@ -118,7 +118,7 @@
   source_class    = GEGL_OPERATION_SOURCE_CLASS (klass);
 
   source_class->process = process;
-  operation_class->get_defined_region = get_defined_region;
+  operation_class->get_bounding_box = get_bounding_box;
   operation_class->prepare = prepare;
 
   operation_class->name        = "checkerboard";

Modified: trunk/operations/render/color.c
==============================================================================
--- trunk/operations/render/color.c	(original)
+++ trunk/operations/render/color.c	Sat Feb  9 20:18:01 2008
@@ -33,7 +33,7 @@
 }
 
 static GeglRectangle
-get_defined_region (GeglOperation *operation)
+get_bounding_box (GeglOperation *operation)
 {
   GeglRectangle result = {-10000000,-10000000,20000000,20000000};
   return result;
@@ -90,7 +90,7 @@
   source_class    = GEGL_OPERATION_SOURCE_CLASS (klass);
 
   source_class->process = process;
-  operation_class->get_defined_region = get_defined_region;
+  operation_class->get_bounding_box = get_bounding_box;
   operation_class->prepare = prepare;
 
   operation_class->name        = "color";

Modified: trunk/operations/render/fractal-explorer.c
==============================================================================
--- trunk/operations/render/fractal-explorer.c	(original)
+++ trunk/operations/render/fractal-explorer.c	Sat Feb  9 20:18:01 2008
@@ -401,7 +401,7 @@
 }
 
 static GeglRectangle
-get_defined_region (GeglOperation *operation)
+get_bounding_box (GeglOperation *operation)
 {
   GeglChantO    *o = GEGL_CHANT_PROPERTIES (operation);
   GeglRectangle  result = {0,0,0,0};
@@ -460,7 +460,7 @@
   source_class    = GEGL_OPERATION_SOURCE_CLASS (klass);
 
   source_class->process = process;
-  operation_class->get_defined_region = get_defined_region;
+  operation_class->get_bounding_box = get_bounding_box;
   operation_class->prepare = prepare;
 
   operation_class->name        = "fractal-explorer";

Modified: trunk/operations/render/introspect.c
==============================================================================
--- trunk/operations/render/introspect.c	(original)
+++ trunk/operations/render/introspect.c	Sat Feb  9 20:18:01 2008
@@ -31,7 +31,7 @@
 #include <string.h>
 
 static GeglRectangle
-get_defined_region (GeglOperation *operation)
+get_bounding_box (GeglOperation *operation)
 {
   GeglChantO *o = GEGL_CHANT_PROPERTIES (operation);
 
@@ -114,7 +114,7 @@
   source_class    = GEGL_OPERATION_SOURCE_CLASS (klass);
 
   source_class->process = process;
-  operation_class->get_defined_region = get_defined_region;
+  operation_class->get_bounding_box = get_bounding_box;
 
   operation_class->name        = "introspect";
   operation_class->categories  = "render";

Modified: trunk/operations/render/noise.c
==============================================================================
--- trunk/operations/render/noise.c	(original)
+++ trunk/operations/render/noise.c	Sat Feb  9 20:18:01 2008
@@ -39,7 +39,7 @@
 }
 
 static GeglRectangle
-get_defined_region (GeglOperation *operation)
+get_bounding_box (GeglOperation *operation)
 {
   GeglRectangle result = {-10000000, -10000000, 20000000, 20000000};
   return result;
@@ -91,7 +91,7 @@
   source_class    = GEGL_OPERATION_SOURCE_CLASS (klass);
 
   source_class->process = process;
-  operation_class->get_defined_region = get_defined_region;
+  operation_class->get_bounding_box = get_bounding_box;
   operation_class->prepare = prepare;
 
   operation_class->name        = "perlin-noise";

Modified: trunk/operations/render/text.c
==============================================================================
--- trunk/operations/render/text.c	(original)
+++ trunk/operations/render/text.c	Sat Feb  9 20:18:01 2008
@@ -195,7 +195,7 @@
 }
 
 static GeglRectangle
-get_defined_region (GeglOperation *operation)
+get_bounding_box (GeglOperation *operation)
 {
   GeglChant *self = GEGL_CHANT (operation);
   GeglChantO           *o = GEGL_CHANT_PROPERTIES (self);
@@ -289,7 +289,7 @@
   operation_class->categories  = "render";
   operation_class->description = "Display a string of text using pango and cairo.";
   operation_class->prepare = prepare;
-  operation_class->get_defined_region = get_defined_region;
+  operation_class->get_bounding_box = get_bounding_box;
   operation_source_class->process = process;
 }
 

Modified: trunk/operations/workshop/box-percentile.c
==============================================================================
--- trunk/operations/workshop/box-percentile.c	(original)
+++ trunk/operations/workshop/box-percentile.c	Sat Feb  9 20:18:01 2008
@@ -58,7 +58,7 @@
 {
   GeglChantO   *o = GEGL_CHANT_PROPERTIES (operation);
   GeglBuffer   *temp_in;
-  GeglRectangle compute = gegl_operation_compute_input_request (operation, "input", result);
+  GeglRectangle compute = gegl_operation_get_invalidated_by_change (operation, "input", result);
 
   if (o->radius < 1.0)
     {

Modified: trunk/operations/workshop/c2g.c
==============================================================================
--- trunk/operations/workshop/c2g.c	(original)
+++ trunk/operations/workshop/c2g.c	Sat Feb  9 20:18:01 2008
@@ -71,7 +71,7 @@
 {
   GeglChantO   *o = GEGL_CHANT_PROPERTIES (operation);
   GeglBuffer   *temp_in;
-  GeglRectangle compute = gegl_operation_compute_input_request (operation, "input", result);
+  GeglRectangle compute = gegl_operation_get_invalidated_by_change (operation, "input", result);
 
   temp_in = gegl_buffer_create_sub_buffer (input, &compute);
 

Modified: trunk/operations/workshop/demosaic-simple.c
==============================================================================
--- trunk/operations/workshop/demosaic-simple.c	(original)
+++ trunk/operations/workshop/demosaic-simple.c	Sat Feb  9 20:18:01 2008
@@ -118,7 +118,7 @@
 {
   GeglChantO   *o = GEGL_CHANT_PROPERTIES (operation);
   GeglBuffer   *temp_in;
-  GeglRectangle compute = gegl_operation_compute_input_request (operation, "input", result);
+  GeglRectangle compute = gegl_operation_get_invalidated_by_change (operation, "input", result);
 
   temp_in = gegl_buffer_create_sub_buffer (input, &compute);
 

Modified: trunk/operations/workshop/disc-percentile.c
==============================================================================
--- trunk/operations/workshop/disc-percentile.c	(original)
+++ trunk/operations/workshop/disc-percentile.c	Sat Feb  9 20:18:01 2008
@@ -190,7 +190,7 @@
   GeglChantO   *o = GEGL_CHANT_PROPERTIES (operation);
   GeglBuffer   *temp_in;
   GeglRectangle compute =
-        gegl_operation_compute_input_request (operation, "input", result);
+        gegl_operation_get_invalidated_by_change (operation, "input", result);
 
   if (o->radius < 1.0)
     {

Modified: trunk/operations/workshop/gluas.c
==============================================================================
--- trunk/operations/workshop/gluas.c	(original)
+++ trunk/operations/workshop/gluas.c	Sat Feb  9 20:18:01 2008
@@ -108,10 +108,10 @@
 }
 
 static GeglRectangle
-get_defined_region (GeglOperation *operation)
+get_bounding_box (GeglOperation *operation)
 {
   GeglRectangle  result = {0,0,0,0};
-  GeglRectangle *in_rect = gegl_operation_source_get_defined_region (operation,
+  GeglRectangle *in_rect = gegl_operation_source_get_bounding_box (operation,
                                                                      "input");
   if (!in_rect)
     return result;
@@ -122,7 +122,7 @@
 
 static void class_init (GeglOperationClass *operation_class)
 {
-  operation_class->get_defined_region  = get_defined_region;
+  operation_class->get_bounding_box  = get_bounding_box;
 }
 
 
@@ -193,7 +193,7 @@
 {
     /*GimpRGB    background;*/
 
-    GeglRectangle *in_rect = gegl_operation_source_get_defined_region (GEGL_OPERATION (self),
+    GeglRectangle *in_rect = gegl_operation_source_get_bounding_box (GEGL_OPERATION (self),
                                                                        "input");
 
     lua_State *L;

Modified: trunk/operations/workshop/hstack.c
==============================================================================
--- trunk/operations/workshop/hstack.c	(original)
+++ trunk/operations/workshop/hstack.c	Sat Feb  9 20:18:01 2008
@@ -34,12 +34,12 @@
 }
 
 static GeglRectangle
-get_defined_region (GeglOperation *operation)
+get_bounding_box (GeglOperation *operation)
 {
   GeglRectangle  result = {0,0,0,0};
-  GeglRectangle *in_rect = gegl_operation_source_get_defined_region (operation,
+  GeglRectangle *in_rect = gegl_operation_source_get_bounding_box (operation,
                                                                      "input");
-  GeglRectangle *aux_rect = gegl_operation_source_get_defined_region (operation,
+  GeglRectangle *aux_rect = gegl_operation_source_get_bounding_box (operation,
                                                                       "aux");
 
   if (!in_rect)
@@ -58,7 +58,7 @@
 }
 
 static GeglRectangle
-compute_input_request (GeglOperation       *self,
+get_invalidated_by_change (GeglOperation       *self,
                        const gchar         *input_pad,
                        const GeglRectangle *roi)
 {
@@ -66,9 +66,9 @@
 
   if (!strcmp (input_pad, "aux"))
     {
-      GeglRectangle *in_rect = gegl_operation_source_get_defined_region (self,
+      GeglRectangle *in_rect = gegl_operation_source_get_bounding_box (self,
                                                                          "input");
-      GeglRectangle *aux_rect = gegl_operation_source_get_defined_region (self,
+      GeglRectangle *aux_rect = gegl_operation_source_get_bounding_box (self,
                                                                          "aux");
 
       if (request.width != 0 &&
@@ -82,7 +82,7 @@
 }
 
 static GeglRectangle
-compute_affected_region (GeglOperation       *self,
+get_required_for_output (GeglOperation       *self,
                          const gchar         *input_pad,
                          const GeglRectangle *region)
 {
@@ -163,9 +163,9 @@
 
   composer_class->process = process;
   operation_class->prepare = prepare;
-  operation_class->get_defined_region = get_defined_region;
-  operation_class->compute_affected_region = compute_affected_region;
-  operation_class->compute_input_request   = compute_input_request;
+  operation_class->get_bounding_box = get_bounding_box;
+  operation_class->get_required_for_output = get_required_for_output;
+  operation_class->get_invalidated_by_change = get_invalidated_by_change;
 
   operation_class->name        = "hstack";
   operation_class->categories  = "misc";

Modified: trunk/operations/workshop/kuwahara-max.c
==============================================================================
--- trunk/operations/workshop/kuwahara-max.c	(original)
+++ trunk/operations/workshop/kuwahara-max.c	Sat Feb  9 20:18:01 2008
@@ -207,7 +207,7 @@
 {
   GeglChantO   *o = GEGL_CHANT_PROPERTIES (operation);
   GeglBuffer   *temp_in;
-  GeglRectangle compute = gegl_operation_compute_input_request (operation, "input", result);
+  GeglRectangle compute = gegl_operation_get_invalidated_by_change (operation, "input", result);
 
   temp_in = gegl_buffer_create_sub_buffer (input, &compute);
 

Modified: trunk/operations/workshop/kuwahara-min.c
==============================================================================
--- trunk/operations/workshop/kuwahara-min.c	(original)
+++ trunk/operations/workshop/kuwahara-min.c	Sat Feb  9 20:18:01 2008
@@ -207,7 +207,7 @@
 {
   GeglChantO   *o = GEGL_CHANT_PROPERTIES (operation);
   GeglBuffer   *temp_in;
-  GeglRectangle compute = gegl_operation_compute_input_request (operation, "input", result);
+  GeglRectangle compute = gegl_operation_get_invalidated_by_change (operation, "input", result);
 
   temp_in = gegl_buffer_create_sub_buffer (input, &compute);
 

Modified: trunk/operations/workshop/kuwahara.c
==============================================================================
--- trunk/operations/workshop/kuwahara.c	(original)
+++ trunk/operations/workshop/kuwahara.c	Sat Feb  9 20:18:01 2008
@@ -207,7 +207,7 @@
 {
   GeglChantO   *o = GEGL_CHANT_PROPERTIES (operation);
   GeglBuffer   *temp_in;
-  GeglRectangle compute = gegl_operation_compute_input_request (operation, "input", result);
+  GeglRectangle compute = gegl_operation_get_invalidated_by_change (operation, "input", result);
 
   temp_in = gegl_buffer_create_sub_buffer (input, &compute);
 

Modified: trunk/operations/workshop/lens-correct.c
==============================================================================
--- trunk/operations/workshop/lens-correct.c	(original)
+++ trunk/operations/workshop/lens-correct.c	Sat Feb  9 20:18:01 2008
@@ -305,20 +305,20 @@
 /* Compute the region for which this operation is defined.
  */
 static GeglRectangle
-get_defined_region (GeglOperation *operation)
+get_bounding_box (GeglOperation *operation)
 {
   GeglRectangle  result = {0,0,0,0};
-  GeglRectangle *in_rect = gegl_operation_source_get_defined_region (operation, "input");
+  GeglRectangle *in_rect = gegl_operation_source_get_bounding_box (operation, "input");
   GeglChantO    *area = GEGL_CHANT_PROPERTIES (operation);
 
   #ifdef TRACE
-    g_warning ("> get_defined_region pointer == 0x%x in_rect == 0x%x", area->lens_info_pointer, in_rect);
+    g_warning ("> get_bounding_box pointer == 0x%x in_rect == 0x%x", area->lens_info_pointer, in_rect);
   #endif
   if (in_rect && area->lens_info_pointer)
     result = map_region (in_rect, area->lens_info_pointer, find_dst_pixel);
 
   #ifdef TRACE
-    g_warning ("< get_defined_region result = %dx%d+%d+%d", result.width, result.height, result.x, result.y);
+    g_warning ("< get_bounding_box result = %dx%d+%d+%d", result.width, result.height, result.x, result.y);
   #endif
   return result;
 }
@@ -326,14 +326,14 @@
 /* Compute the input rectangle required to compute the specified region of interest (roi).
  */
 static GeglRectangle
-compute_input_request (GeglOperation       *operation,
-                       const gchar         *input_pad,
-                       const GeglRectangle *roi)
+get_invalidated_by_change (GeglOperation       *operation,
+                           const gchar         *input_pad,
+                           const GeglRectangle *roi)
 {
   GeglChantO   *area = GEGL_CHANT_PROPERTIES (operation);
-  GeglRectangle result = *gegl_operation_source_get_defined_region (operation, "input");
+  GeglRectangle result = *gegl_operation_source_get_bounding_box (operation, "input");
   #ifdef TRACE
-    g_warning ("> compute_input_request src=%dx%d+%d+%d", result.width, result.height, result.x, result.y);
+    g_warning ("> get_invalidated_by_change src=%dx%d+%d+%d", result.width, result.height, result.x, result.y);
     if (roi)
       g_warning ("  ROI == %dx%d+%d+%d", roi->width, roi->height, roi->x, roi->y);
   #endif
@@ -343,7 +343,7 @@
     result.height++;
   }
   #ifdef TRACE
-    g_warning ("< compute_input_request res=%dx%d+%d+%d", result.width, result.height, result.x, result.y);
+    g_warning ("< get_invalidated_by_change res=%dx%d+%d+%d", result.width, result.height, result.x, result.y);
   #endif
   return result;
 }
@@ -390,8 +390,8 @@
 
   filter_class->process = process;
   operation_class->prepare = prepare;
-  operation_class->get_defined_region = get_defined_region;
-  operation_class->compute_input_request = compute_input_request;
+  operation_class->get_bounding_box = get_bounding_box;
+  operation_class->get_invalidated_by_change = get_invalidated_by_change;
 
   operation_class->name        = "lens-correct";
   operation_class->categories  = "blur";

Modified: trunk/operations/workshop/line-profile.c
==============================================================================
--- trunk/operations/workshop/line-profile.c	(original)
+++ trunk/operations/workshop/line-profile.c	Sat Feb  9 20:18:01 2008
@@ -133,15 +133,15 @@
 }
 
 static GeglRectangle
-compute_input_request (GeglOperation       *self,
+get_invalidated_by_change (GeglOperation       *self,
                        const gchar         *input_pad,
                        const GeglRectangle *roi)
 {
-  return *gegl_operation_source_get_defined_region (self, "input");
+  return *gegl_operation_source_get_bounding_box (self, "input");
 }
 
 static GeglRectangle
-get_defined_region (GeglOperation *operation)
+get_bounding_box (GeglOperation *operation)
 {
   GeglChantO   *o = GEGL_CHANT_PROPERTIES (operation);
   GeglRectangle defined = {0,0,o->width,o->height};
@@ -162,8 +162,8 @@
   filter_class    = GEGL_OPERATION_FILTER_CLASS (klass);
 
   filter_class->process = process;
-  operation_class->compute_input_request = compute_input_request;
-  operation_class->get_defined_region = get_defined_region;
+  operation_class->get_invalidated_by_change = get_invalidated_by_change;
+  operation_class->get_bounding_box = get_bounding_box;
 
   operation_class->name        = "line-profile";
   operation_class->categories  = "debug";

Modified: trunk/operations/workshop/mandelbrot.c
==============================================================================
--- trunk/operations/workshop/mandelbrot.c	(original)
+++ trunk/operations/workshop/mandelbrot.c	Sat Feb  9 20:18:01 2008
@@ -68,7 +68,7 @@
 }
 
 static GeglRectangle
-get_defined_region (GeglOperation *operation)
+get_bounding_box (GeglOperation *operation)
 {
   GeglRectangle result = {-256,-256, 1024, 1024};
   return result;
@@ -131,7 +131,7 @@
 
   source_class->process = process;
   operation_class->prepare = prepare;
-  operation_class->get_defined_region = get_defined_region;
+  operation_class->get_bounding_box = get_bounding_box;
 
   operation_class->name        = "mandelbrot";
   operation_class->categories  = "render";

Modified: trunk/operations/workshop/max-envelope.c
==============================================================================
--- trunk/operations/workshop/max-envelope.c	(original)
+++ trunk/operations/workshop/max-envelope.c	Sat Feb  9 20:18:01 2008
@@ -39,12 +39,12 @@
 #include "envelopes.h"
 
 static void max_envelope (GeglBuffer *src,
-                          GeglBuffer *dst,
-                          gint        radius,
-                          gint        samples,
-                          gint        iterations,
-                          gboolean    same_spray,
-                          gdouble     rgamma)
+                            GeglBuffer *dst,
+                            gint        radius,
+                            gint        samples,
+                            gint        iterations,
+                            gboolean    same_spray,
+                            gdouble     rgamma)
 {
   gint    x, y;
   gfloat *src_buf;
@@ -103,7 +103,7 @@
 {
   GeglChantO   *o = GEGL_CHANT_PROPERTIES (operation);
   GeglBuffer   *temp_in;
-  GeglRectangle compute = gegl_operation_compute_input_request (operation, "input", result);
+  GeglRectangle compute = gegl_operation_get_invalidated_by_change (operation, "input", result);
 
   if (o->radius < 1.0)
     {

Modified: trunk/operations/workshop/min-envelope.c
==============================================================================
--- trunk/operations/workshop/min-envelope.c	(original)
+++ trunk/operations/workshop/min-envelope.c	Sat Feb  9 20:18:01 2008
@@ -103,7 +103,7 @@
 {
   GeglChantO   *o = GEGL_CHANT_PROPERTIES (operation);
   GeglBuffer   *temp_in;
-  GeglRectangle compute  = gegl_operation_compute_input_request (operation, "input", result);
+  GeglRectangle compute  = gegl_operation_get_invalidated_by_change (operation, "input", result);
 
   if (o->radius < 1.0)
     {

Modified: trunk/operations/workshop/rawbayer-load.c
==============================================================================
--- trunk/operations/workshop/rawbayer-load.c	(original)
+++ trunk/operations/workshop/rawbayer-load.c	Sat Feb  9 20:18:01 2008
@@ -57,7 +57,7 @@
 
 
 static GeglRectangle
-get_defined_region (GeglOperation *operation)
+get_bounding_box (GeglOperation *operation)
 {
   GeglRectangle result = {0,0,0,0};
   GeglChantOperation *self = GEGL_CHANT_OPERATION (operation);

Modified: trunk/operations/workshop/snn-percentile.c
==============================================================================
--- trunk/operations/workshop/snn-percentile.c	(original)
+++ trunk/operations/workshop/snn-percentile.c	Sat Feb  9 20:18:01 2008
@@ -228,7 +228,7 @@
 {
   GeglChantO   *o = GEGL_CHANT_PROPERTIES (operation);
   GeglBuffer   *temp_in;
-  GeglRectangle compute  = gegl_operation_compute_input_request (operation, "input", result);
+  GeglRectangle compute  = gegl_operation_get_invalidated_by_change (operation, "input", result);
 
   if (result->width == 0 ||
       result->height== 0 ||

Modified: trunk/operations/workshop/stress.c
==============================================================================
--- trunk/operations/workshop/stress.c	(original)
+++ trunk/operations/workshop/stress.c	Sat Feb  9 20:18:01 2008
@@ -125,10 +125,10 @@
 }
 
 static GeglRectangle
-get_defined_region (GeglOperation *operation)
+get_bounding_box (GeglOperation *operation)
 {
   GeglRectangle  result = {0,0,0,0};
-  GeglRectangle *in_rect = gegl_operation_source_get_defined_region (operation,
+  GeglRectangle *in_rect = gegl_operation_source_get_bounding_box (operation,
                                                                      "input");
   if (!in_rect)
     return result;
@@ -172,7 +172,7 @@
    * in the image as source data not to be skipped by the stochastic sampling
    * yielding correct edge behavior.
    */
-  operation_class->get_defined_region = get_defined_region;
+  operation_class->get_bounding_box = get_bounding_box;
 
   operation_class->name        = "stress";
   operation_class->categories  = "enhance";



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
--- trunk/gegl/operation/gegl-operations.c	(original)
+++ trunk/gegl/operation/gegl-operations.c	Sat Feb  9 20:18:01 2008
@@ -135,12 +135,12 @@
   context = gegl_node_get_context (operation->node, context_id);
   request = context->need_rect;
 
   /* for each input, compute_input_request use gegl_operation_set_source_region() */
   for (input_pads = operation->node->input_pads;input_pads;input_pads=input_pads->next)
     {
       const gchar *pad_name = gegl_pad_get_name (input_pads->data);
       GeglRectangle rect;
-      rect = gegl_operation_compute_input_request (operation, pad_name, &request); 
+      rect = gegl_operation_get_invalidated_by_change (operation, pad_name, &request); 
 
       gegl_operation_set_source_region (operation, context_id, pad_name, &rect);
     }
@@ -135,12 +135,12 @@
   request = context->need_rect;
 
-  /* for each input, compute_input_request use gegl_operation_set_source_region() */
+  /* for each input, get_invalidated_by_change use gegl_operation_set_source_region() */
   for (input_pads = operation->node->input_pads;input_pads;input_pads=input_pads->next)
     {

Modified: trunk/gegl/process/gegl-have-visitor.c
==============================================================================